==> gridstack-8.x-2.7.tar.gz: gridstack/js/gridstack.load.js <==
/**
 * @file
 * Provides loader for js-driven layout using GridStack JS library, or builtin.
 */

(function (Drupal, _db) {

  'use strict';

  Drupal.gridstack = Drupal.gridstack || {};

  /**
   * GridStack front-end public methods.
   *
   * @namespace
   */
  Drupal.gridstack.gs = _db.extend({}, Drupal.gridstack.fe || {}, {

    onClass: 'gs',

    gsSettings: {
      // A trick to ignore height calculation with dummy sizer.
      placeholderClass: 'gridstack__sizer',
      // Will manually do 1 column = true.
      // float: true
      disableOneColumnMode: true,
      // Hard-code previously configurable settings due to deprecation.
      staticGrid: true,
      draggable: false,
      resizable: false,
      disableDrag: true,
      disableResize: true,
      alwaysShowResizeHandle: false,
      // If false grid will be static.
      // (default?: null - first available plugin will be used)
      ddPlugin: false
    },

    isGridStatic: function (el) {
      return el.classList.contains('gridstack--static');
    },

    fixAspectRatio: function (el) {
      var me = this;
      var ch = me.options.cellHeight;
      var ok = ch === 'auto' || (me.cellHeight >= ch && me.cellHeight < (ch * 2));
      var vm = me.vm > 0 ? (me.vm / 2) : 0;

      me.options.dataset = me.getData(el);
      if (me.isValid(me.$instance)) {
        if (typeof me.$instance.prepareNodes === 'function') {
          me.$instance.prepareNodes(me.options.dataset);
        }
      }

      // Requires to determine the correct aspect ratio as otherwise weird.
      if (me.isEnabled(el)) {
        me.cellHeight = ok ? (me.cellHeight - vm) : ch;
        me.options.cellHeight = me.cellHeight;

        // No need to change it within LB due to frequent AJAX reloads.
        if (!me.isLayoutBuilder && (me.isValid(me.$instance) && me.isValid(me.$instance._styles))) {
          me.$instance.cellHeight(me.cellHeight);
        }
      }
    },

    updateAttribute: function (box, item, el, e) {
      var me = this;

      // Params: el, x, y, width, height.
      // For some reasons, instance.update is too slow to work with resizing.
      _db.forEach(['x', 'y', 'width', 'height'], function (node, i) {
        box.setAttribute('data-gs-' + node, item[i]);
      });

      me.$instance.update(box, item[0], item[1], item[2], item[3]);
    },

    postUpdateGrid: function (el, e) {
      var me = this;

      me.$instance.column(me.column(el));
    },

    destroy: function (el) {
      var me = this;

      me.$instance.destroy(false);

      el.classList.add('is-gs-destroyed');
      el.removeAttribute('style');
    },

    init: function (el) {
      var me = this;

      me.$el = el;

      me.prepare(el);

      // Unlike native Grid Layout, fixed aspect ratio earlier, before layouts.
      // Runs it before init to pass the options to gridstack.
      me.updateSizer(el);

      me.$instance = me.isGridStatic(el) ? GridStatic.init(me.options, el) : GridStack.init(me.options, el);

      me.buildOut(el);
      me.cleanUp(el);
    }

  });

  /**
   * Attaches behavior to HTML element identified by .gridstack--gs.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.gridstackGs = {
    attach: function (context) {
      if ('length' in context) {
        context = context[0];
      }

      var me = Drupal.gridstack.gs;
      var elms = context.querySelectorAll('.gridstack--gs:not(.is-gs-on)');
      if (elms.length > 0) {
        _db.once(_db.forEach(elms, me.init.bind(me), context));
      }
    }
  };

})(Drupal, dBlazy);

==> gridstack-8.x-2.8.tar.gz: gridstack/js/gridstack.load.js <==
/**
 * @file
 * Provides loader for js-driven layout using GridStack JS library, or builtin.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.gridstack = Drupal.gridstack || {};

  /**
   * GridStack front-end public methods.
   *
   * @namespace
   */
  Drupal.gridstack.gs = $.extend({}, Drupal.gridstack.fe || {}, {

    onClass: 'gs',

    gsSettings: {
      // A trick to ignore height calculation with dummy sizer.
      placeholderClass: 'gridstack__sizer',
      // Will manually do 1 column = true.
      // float: true
      disableOneColumnMode: true,
      // Hard-code previously configurable settings due to deprecation.
      staticGrid: true,
      draggable: false,
      resizable: false,
      disableDrag: true,
      disableResize: true,
      alwaysShowResizeHandle: false,
      // If false grid will be static.
      // (default?: null - first available plugin will be used)
      ddPlugin: false
    },

    isGridStatic: function (el) {
      return el.classList.contains('gridstack--static');
    },

    fixAspectRatio: function (el) {
      var me = this;
      var ch = me.options.cellHeight;
      var ok = ch === 'auto' || (me.cellHeight >= ch && me.cellHeight < (ch * 2));
      var vm = me.vm > 0 ? (me.vm / 2) : 0;

      me.options.dataset = me.getData(el);
      if (me.isValid(me.$instance)) {
        if (typeof me.$instance.prepareNodes === 'function') {
          me.$instance.prepareNodes(me.options.dataset);
        }
      }

      // Requires to determine the correct aspect ratio as otherwise weird.
      if (me.isEnabled(el)) {
        me.cellHeight = ok ? (me.cellHeight - vm) : ch;
        me.options.cellHeight = me.cellHeight;

        // No need to change it within LB due to frequent AJAX reloads.
        if (!me.isLayoutBuilder && (me.isValid(me.$instance) && me.isValid(me.$instance._styles))) {
          me.$instance.cellHeight(me.cellHeight);
        }
      }
    },

    updateAttribute: function (box, item, el, e) {
      var me = this;

      // Params: el, {x, y, w, h}.
      // For some reasons, instance.update is too slow to work with resizing.
      $.forEach(['x', 'y', 'w', 'h'], function (node, i) {
        box.setAttribute('gs-' + node, item[i]);
      });

      var opts = {x: item[0], y: item[1], w: item[2], h: item[3]};
      me.$instance.update(box, opts);
    },

    postUpdateGrid: function (el, e) {
      var me = this;

      me.$instance.column(me.column(el));
    },

    destroy: function (el) {
      var me = this;

      me.$instance.destroy(false);

      el.classList.add('is-gs-destroyed');
      el.removeAttribute('style');
    },

    init: function (el) {
      var me = this;

      me.$el = el;

      me.prepare(el);

      // Unlike native Grid Layout, fixed aspect ratio earlier, before layouts.
      // Runs it before init to pass the options to gridstack.
      me.updateSizer(el);

      var elm = 'length' in el ? el[0] : el;
      me.$instance = me.isGridStatic(el) ? GridStatic.init(me.options, el) : GridStack.init(me.options, elm);

      me.buildOut(el);
      me.cleanUp(el);
    }

  });

  /**
   * Attaches behavior to HTML element identified by .gridstack--gs.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.gridstackGs = {
    attach: function (context) {

      var me = Drupal.gridstack.gs;

      // Context is unreliable with AJAX contents.
      context = me.context(context);

      var elms = context.querySelectorAll('.gridstack--gs:not(.is-gs-on)');
      if (elms.length > 0) {
        $.once($.forEach(elms, me.init.bind(me), context));
      }
    }
  };

})(dBlazy, Drupal);
